hclib
=====

.. image:: https://snyk.io/test/github/neelkamath/hclib/badge.svg?targetFile=requirements.txt
    :target: https://snyk.io/test/github/neelkamath/hclib?targetFile=requirements.txt

.. image:: https://img.shields.io/pypi/v/hclib.svg
    :target: https://pypi.python.org/pypi/hclib

This is a library to connect to `hack.chat <https://hack.chat/>`_

Get it: :code:`pip3 install hclib`

To view documentation:

1. Start the REPL (:code:`python` on Windows and :code:`python3` on others).

2. Import the module: :code:`import hclib`.

3. Print the documentation: :code:`help(hclib)`. 

Contributing
------------

- `Code of Conduct <https://github.com/neelkamath/hclib/blob/v0.1.21/CODE_OF_CONDUCT.md.md>`_

Installation
~~~~~~~~~~~~

1. You'll need `Python 3 or higher <https://www.python.org/downloads/>`_ or higher.
2. Clone the repositry: :code:`git clone https://github.com/neelkamath/hclib.git`
3. Change the directory: :code:`cd hclib`.
4. Run the script (:code:`python hclib.py` on Windows and :code:`python3 hclib.py` on others).

License
=======

This project is under the `MIT License <https://github.com/neelkamath/hclib/blob/v0.1.21/LICENSE>`_.
